@@ -21,10 +21,13 @@ import (
 	"path/filepath"
 	"strings"
 	"time"
+	"unicode"
 
 	"github.com/cespare/xxhash"
 	"github.com/kalafut/imohash"
+	"github.com/minio/highwayhash"
 	"github.com/schollz/mnemonicode"
+	"github.com/schollz/progressbar/v3"
 )
 
 const NbPinNumbers = 4
@@ -76,7 +79,11 @@ func GetInput(prompt string) string {
 
 // HashFile returns the hash of a file or, in case of a symlink, the
 // SHA256 hash of its target. Takes an argument to specify the algorithm to use.
-func HashFile(fname string, algorithm string) (hash256 []byte, err error) {
+func HashFile(fname string, algorithm string, showProgress ...bool) (hash256 []byte, err error) {
+	doShowProgress := false
+	if len(showProgress) > 0 {
+		doShowProgress = showProgress[0]
+	}
 	var fstats os.FileInfo
 	fstats, err = os.Lstat(fname)
 	if err != nil {
@@ -94,16 +101,59 @@ func HashFile(fname string, algorithm string) (hash256 []byte, err error) {
 	case "imohash":
 		return IMOHashFile(fname)
 	case "md5":
-		return MD5HashFile(fname)
+		return MD5HashFile(fname, doShowProgress)
 	case "xxhash":
-		return XXHashFile(fname)
+		return XXHashFile(fname, doShowProgress)
+	case "highway":
+		return HighwayHashFile(fname, doShowProgress)
 	}
 	err = fmt.Errorf("unspecified algorithm")
 	return
 }
 
+// HighwayHashFile returns highwayhash of a file
+func HighwayHashFile(fname string, doShowProgress bool) (hashHighway []byte, err error) {
+	f, err := os.Open(fname)
+	if err != nil {
+		return
+	}
+	defer f.Close()
+	key, err := hex.DecodeString("1553c5383fb0b86578c3310da665b4f6e0521acf22eb58a99532ffed02a6b115")
+	if err != nil {
+		return
+	}
+	h, err := highwayhash.New(key)
+	if err != nil {
+		err = fmt.Errorf("could not create highwayhash: %s", err.Error())
+		return
+	}
+	if doShowProgress {
+		stat, _ := f.Stat()
+		fnameShort := path.Base(fname)
+		if len(fnameShort) > 20 {
+			fnameShort = fnameShort[:20] + "..."
+		}
+		bar := progressbar.NewOptions64(stat.Size(),
+			progressbar.OptionSetWriter(os.Stderr),
+			progressbar.OptionShowBytes(true),
+			progressbar.OptionSetDescription(fmt.Sprintf("Hashing %s", fnameShort)),
+			progressbar.OptionClearOnFinish(),
+		)
+		if _, err = io.Copy(io.MultiWriter(h, bar), f); err != nil {
+			return
+		}
+	} else {
+		if _, err = io.Copy(h, f); err != nil {
+			return
+		}
+	}
+
+	hashHighway = h.Sum(nil)
+	return
+}
+
 // MD5HashFile returns MD5 hash
-func MD5HashFile(fname string) (hash256 []byte, err error) {
+func MD5HashFile(fname string, doShowProgress bool) (hash256 []byte, err error) {
 	f, err := os.Open(fname)
 	if err != nil {
 		return
@@ -111,8 +161,25 @@ func MD5HashFile(fname string) (hash256 []byte, err error) {
 	defer f.Close()
 
 	h := md5.New()
-	if _, err = io.Copy(h, f); err != nil {
-		return
+	if doShowProgress {
+		stat, _ := f.Stat()
+		fnameShort := path.Base(fname)
+		if len(fnameShort) > 20 {
+			fnameShort = fnameShort[:20] + "..."
+		}
+		bar := progressbar.NewOptions64(stat.Size(),
+			progressbar.OptionSetWriter(os.Stderr),
+			progressbar.OptionShowBytes(true),
+			progressbar.OptionSetDescription(fmt.Sprintf("Hashing %s", fnameShort)),
+			progressbar.OptionClearOnFinish(),
+		)
+		if _, err = io.Copy(io.MultiWriter(h, bar), f); err != nil {
+			return
+		}
+	} else {
+		if _, err = io.Copy(h, f); err != nil {
+			return
+		}
 	}
 
 	hash256 = h.Sum(nil)
@@ -136,7 +203,7 @@ func IMOHashFileFull(fname string) (hash []byte, err error) {
 }
 
 // XXHashFile returns the xxhash of a file
-func XXHashFile(fname string) (hash256 []byte, err error) {
+func XXHashFile(fname string, doShowProgress bool) (hash256 []byte, err error) {
 	f, err := os.Open(fname)
 	if err != nil {
 		return
@@ -144,8 +211,25 @@ func XXHashFile(fname string) (hash256 []byte, err error) {
 	defer f.Close()
 
 	h := xxhash.New()
-	if _, err = io.Copy(h, f); err != nil {
-		return
+	if doShowProgress {
+		stat, _ := f.Stat()
+		fnameShort := path.Base(fname)
+		if len(fnameShort) > 20 {
+			fnameShort = fnameShort[:20] + "..."
+		}
+		bar := progressbar.NewOptions64(stat.Size(),
+			progressbar.OptionSetWriter(os.Stderr),
+			progressbar.OptionShowBytes(true),
+			progressbar.OptionSetDescription(fmt.Sprintf("Hashing %s", fnameShort)),
+			progressbar.OptionClearOnFinish(),
+		)
+		if _, err = io.Copy(io.MultiWriter(h, bar), f); err != nil {
+			return
+		}
+	} else {
+		if _, err = io.Copy(h, f); err != nil {
+			return
+		}
 	}
 
 	hash256 = h.Sum(nil)
@@ -485,16 +569,21 @@ func UnzipDirectory(destination string, source string) error {
 }
 
 // ValidFileName checks if a filename is valid
-// and returns true only if it all of the characters are either
-// 0-9, a-z, A-Z, ., _, -, space, or /
+// by making sure it has no invisible characters
 func ValidFileName(fname string) bool {
-	for _, r := range fname {
-		if !((r >= '0' && r <= '9') ||
-			(r >= 'a' && r <= 'z') ||
-			(r >= 'A' && r <= 'Z') ||
-			r == '.' || r == '_' || r == '-' || r == ' ' || r == '/') {
-			return false
+	clean1 := strings.Map(func(r rune) rune {
+		if unicode.IsGraphic(r) {
+			return r
 		}
-	}
-	return true
+		return -1
+	}, fname)
+
+	clean2 := strings.Map(func(r rune) rune {
+		if unicode.IsPrint(r) {
+			return r
+		}
+		return -1
+	}, fname)
+
+	return (fname == clean1) && (fname == clean2)
 }
